@@ -18,10 +18,11 @@ A Perl Class is a Perl Package with an OO interface.
 
 use strict;
 use warnings;
+use utf8;
 
 package Devel::PerlySense::Class;
-BEGIN {
-  $Devel::PerlySense::Class::VERSION = '0.0207';
+{
+  $Devel::PerlySense::Class::VERSION = '0.0208';
 }
 
 
@@ -499,6 +500,8 @@ sub oLocationSub {
 
 __END__
 
+=encoding utf8
+
 =head1 AUTHOR
 
 Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
