@@ -11,10 +11,11 @@ during a parse
 
 use strict;
 use warnings;
+use utf8;
 
 package Devel::PerlySense::Document::Meta;
-BEGIN {
-  $Devel::PerlySense::Document::Meta::VERSION = '0.0207';
+{
+  $Devel::PerlySense::Document::Meta::VERSION = '0.0208';
 }
 
 
@@ -630,6 +631,8 @@ sub oLocationSub {
 
 __END__
 
+=encoding utf8
+
 =head1 AUTHOR
 
 Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
