@@ -13,10 +13,11 @@ Devel::PerlySense::Editor - Integration with editors
 
 use strict;
 use warnings;
+use utf8;
 
 package Devel::PerlySense::Editor;
-BEGIN {
-  $Devel::PerlySense::Editor::VERSION = '0.0207';
+{
+  $Devel::PerlySense::Editor::VERSION = '0.0208';
 }
 
 
@@ -646,6 +647,8 @@ sub stripTrailingWhitespace {
 
 __END__
 
+=encoding utf8
+
 =head1 AUTHOR
 
 Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
