@@ -13,10 +13,11 @@ Devel::PerlySense::Editor::Vim - Integration with Vim
 
 use strict;
 use warnings;
+use utf8;
 
 package Devel::PerlySense::Editor::Vim;
-BEGIN {
-  $Devel::PerlySense::Editor::Vim::VERSION = '0.0207';
+{
+  $Devel::PerlySense::Editor::Vim::VERSION = '0.0208';
 }
 use base "Devel::PerlySense::Editor";
 
@@ -123,6 +124,8 @@ sub escapeValue {
 
 __END__
 
+=encoding utf8
+
 =head1 AUTHOR
 
 Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
